@@ -1,6 +1,6 @@
 /*
  *  Queue load balancing system
- *  $Revision: 1.4 $
+ *  $Revision: 1.5 $
  *
  *  Copyright (C) 1998, 1999 Werner G. Krebs
  *
@@ -137,7 +137,12 @@ else send(fdsocket2,&sig,sizeof(sig),0);
 if ((signal == SIGCONT)&&(ttyinput)) {
 /*Need to do something more aggressive than this to solve for
 bg/fg bug.*/
+#ifdef TCSANOW
+  /*IRIX*/
+tcsetattr(0,TCSANOW,&myterm);
+#else
 tcsetattr(0,0,&myterm);
+#endif
 }
 }
 
@@ -1052,7 +1057,12 @@ if(ttyoutput) myterm.c_oflag &= ~OPOST;
      myterm.c_cc[VMIN]=1;
 #endif
      myterm.c_cc[VTIME]=1;
+#ifdef TCSANOW
+     /*IRIX*/
+     tcsetattr(0,TCSANOW,&myterm);
+#else
      tcsetattr(0,0,&myterm);
+#endif
    }
 
 
@@ -1195,7 +1205,11 @@ be the most portable version:*/
 					mysignal.sa_flags = SA_RESTART;
 #endif
 
+#ifdef TCSANOW
+			if(ttyinput)    tcsetattr(0,TCSANOW,&globalterm);
+#else
 			if(ttyinput)    tcsetattr(0,0,&globalterm);
+#endif
 #ifdef __hpux
 					sigvector((int) -val,&mysignal,NULL);
 #else
@@ -1247,7 +1261,12 @@ read flag and exit loop.*/
 			} while (FD_ISSET(fdsocket2, &readf) ||
 				 FD_ISSET(newsocket, &readf)||FD_ISSET(fdsocket3,&urgfrom));
    exit:
+#ifdef TCSANOW
+			/*IRIX*/
+if(ttyinput) tcsetattr(0,TCSANOW,&globalterm);
+#else
 if(ttyinput) tcsetattr(0,0,&globalterm);
+#endif /*TCSANOW*/
      exit(estatus);
    }
 }
@@ -1302,7 +1321,7 @@ Usage()
    fprintf(stderr,"-h hostname or --host hostname: force queue to run on hostname.\n");
    fprintf(stderr,"-H hostname or --robust-host hostname: Run job on hostname if it is up.\n");
    fprintf(stderr,"-i|-q or --immediate|--queue: Toggle between immediate and queue mode, default is to queue, which requires specification of a spooldir.\n");
-   fprintf(stderr,"[-d spooldir] or [--spooldir spooldir] specifies the name of the batch processing directory, e.g., matlab\n");
+   fprintf(stderr,"[-d spooldir] or [--spooldir spooldir] specifies the name of the batch processing directory, e.g., gnulab\n");
    fprintf(stderr,"-o|-p|-n or --half-pty|--full-pty|--no-pty: Toggle between half pty emulation, full pty emulation, and the more efficient no pty emulation.\n");
    fprintf(stderr,"-w|-r or --wait|--batch Toggle between wait (stub daemon) and return (mail batch) mode, default depends on invocation command.\n");
    fprintf(stderr,"-v or --version: Version\n");
